==> qutim_0.2.60-maemo-8.tar.gz: qutim-0.2.60-maemo/translations/ru_RU/nowplaying.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>Author</name>
    <message>
        <location filename="../../src/nowplaying.cpp" line="+32"/>
        <source>Kazlauskas Ian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alexey Prokhin</source>
        <translation>Алексей Прохин</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ruslan Nigmatullin</source>
        <translation>Руслан Нигматуллин</translation>
    </message>
</context>
<context>
    <name>IcqSettings</name>
    <message>
        <location filename="../../src/icqsettings.ui" line="+14"/>
        <source>ICQ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current mode</source>
        <translation type="unfinished">Текущий режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Deactivated</source>
        <translation type="unfinished">Отключен</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Changes current X-status message</source>
        <translation type="unfinished">Изменять сообщение текущего Х-статуса</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+33"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;table style=&quot;-qt-table-type: root; margin-top:4px; margin-bottom:4px; margin-left:4px; margin-right:4px;&quot;&gt;
&lt;tr&gt;
&lt;td style=&quot;border: none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%artist - artist&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%title - title&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%album - album&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%track - track number&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%time - track length&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%file - file name&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%uri - full path to file&lt;/span&gt;&lt;/p&gt;&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;table style=&quot;-qt-table-type: root; margin-top:4px; margin-bottom:4px; margin-left:4px; margin-right:4px;&quot;&gt;
&lt;tr&gt;
&lt;td style=&quot;border: none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%artist - Исполнитель&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%title - Название&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%album - Альбом&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%track - Номер записи&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%time - Длина записи&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%file - Имя файла&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%uri - Полный путь к файлу&lt;/span&gt;&lt;/p&gt;&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Now playing: %artist - %title</source>
        <translation type="unfinished">В колонках гремит: %artist - %title</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Changes message of &quot;Listening to music&quot; status</source>
        <translation type="unfinished">Изменять сообщение статуса &quot;Слушаю музыку&quot;</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>%artist - %title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberSettings</name>
    <message>
        <location filename="../../src/jabbersettings.ui" line="+14"/>
        <source>Jabber</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current mode</source>
        <translation type="unfinished">Текущий режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Deactivated</source>
        <translation type="unfinished">Отключен</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Activated</source>
        <translation type="unfinished">Включен</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Info to be presented</source>
        <translation type="unfinished">Что показывать</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Track number</source>
        <translation>Номер записи</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Title</source>
        <translation>Название записи</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Track length</source>
        <translation>Длина записи</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Path to file</source>
        <translation>Путь к файлу</translation>
    </message>
</context>
<context>
    <name>NowPlaying</name>
    <message>
        <location filename="../../src/nowplaying.cpp" line="+39"/>
        <source>Now Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+184"/>
        <source>Stop now playing</source>
        <translation type="unfinished">Стоп &quot;Сейчас играет&quot;</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start now playing</source>
        <translation type="unfinished">Пуск &quot;Сейчас играет&quot;</translation>
    </message>
</context>
<context>
    <name>NowPlayingSettings</name>
    <message>
        <location filename="../../src/nowplayingsettings.ui" line="+17"/>
        <source>Form</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current plugin status:</source>
        <translation type="unfinished">Текущее состояние плагина:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Is working</source>
        <translation type="unfinished">работает</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Stop</source>
        <translation type="unfinished">Остановить</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Set mode for all accounts</source>
        <translation type="unfinished">Установить для всех аккаунтов</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>You have no Oscar, Jabber or MRIM accounts.</source>
        <translation type="unfinished">У вас нет учетных записей ICQ/Oscar, XMPP/jabber или Mail.ru агента.</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Music Player</source>
        <translation type="unfinished">Музыкальный плеер</translation>
    </message>
    <message>
        <source>Hostname</source>
        <translation type="obsolete">Имя  хоста</translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="obsolete">Порт</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Пароль</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../src/nowplaying.cpp" line="-233"/>
        <source>Now Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Now playing plugin</source>
        <translation type="unfinished">Now playing плагин</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Now Playing Mpris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mpris support for now playing plugin</source>
        <translation type="unfinished">Поддержка Mpris для now playing плагина</translation>
    </message>
    <message>
        <source>Amarok 2 support for now playing plugin</source>
        <translation type="obsolete">Поддержка Amarok2 для плагина now playing</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location line="-9"/>
        <location line="+3"/>
        <location line="+3"/>
        <source>Developer</source>
        <translation type="unfinished">Разработчик</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::nowplaying::SettingsUI</name>
    <message>
        <location filename="../../src/settingsui.cpp" line="+136"/>
        <source>working</source>
        <translation type="unfinished">работает</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>not working</source>
        <translation type="unfinished">не работает</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start</source>
        <translation type="unfinished">Пуск</translation>
    </message>
</context>
</TS>

==> qutim_0.2.80-maemo-8.tar.gz: qutim-0.2.80-maemo/translations/ru_RU/nowplaying.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>Author</name>
    <message>
        <location filename="../../plugins/nowplaying/src/nowplaying.cpp" line="+33"/>
        <source>Kazlauskas Ian</source>
        <translatorcomment>Каслаускас Йен</translatorcomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alexey Prokhin</source>
        <translation>Прохин Алексей</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ruslan Nigmatullin</source>
        <translation>Нигматуллин Руслан</translation>
    </message>
</context>
<context>
    <name>IcqSettings</name>
    <message>
        <location filename="../../plugins/nowplaying/src/icqsettings.ui" line="+14"/>
        <source>ICQ</source>
        <translation></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current mode</source>
        <translation>Текущий режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Deactivated</source>
        <translation>Отключен</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Changes current X-status message</source>
        <translation>Изменять сообщение текущего Х-статуса</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+33"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;table style=&quot;-qt-table-type: root; margin-top:4px; margin-bottom:4px; margin-left:4px; margin-right:4px;&quot;&gt;
&lt;tr&gt;
&lt;td style=&quot;border: none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%artist - artist&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%title - title&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%album - album&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%track - track number&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%time - track length&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%file - file name&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%uri - full path to file&lt;/span&gt;&lt;/p&gt;&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;table style=&quot;-qt-table-type: root; margin-top:4px; margin-bottom:4px; margin-left:4px; margin-right:4px;&quot;&gt;
&lt;tr&gt;
&lt;td style=&quot;border: none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%artist - Исполнитель&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%title - Название&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%album - Альбом&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%track - Номер записи&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%time - Длина записи&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%file - Имя файла&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%uri - Полный путь к файлу&lt;/span&gt;&lt;/p&gt;&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Now playing: %artist - %title</source>
        <translation>В колонках гремит: %artist - %title</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Changes message of &quot;Listening to music&quot; status</source>
        <translation>Изменять сообщение статуса &quot;Слушаю музыку&quot;</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>%artist - %title</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>JabberSettings</name>
    <message>
        <location filename="../../plugins/nowplaying/src/jabbersettings.ui" line="+14"/>
        <source>Jabber</source>
        <translation></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current mode</source>
        <translation>Текущий режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Deactivated</source>
        <translation>Отключен</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Activated</source>
        <translation>Включен</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Info to be presented</source>
        <translation>Что показывать</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Track number</source>
        <translation>Номер записи</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Title</source>
        <translation>Название записи</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Track length</source>
        <translation>Длина записи</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Path to file</source>
        <translation>Путь к файлу</translation>
    </message>
</context>
<context>
    <name>NowPlaying</name>
    <message>
        <location filename="../../plugins/nowplaying/src/nowplaying.cpp" line="+39"/>
        <source>Now Playing</source>
        <translation>Сейчас играет</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Stop now playing</source>
        <translation type="unfinished">Остановить &quot;Сейчас играет&quot;</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start now playing</source>
        <translation type="unfinished">Запустить &quot;Сейчас играет&quot;</translation>
    </message>
</context>
<context>
    <name>NowPlayingSettings</name>
    <message>
        <location filename="../../plugins/nowplaying/src/nowplayingsettings.ui" line="+17"/>
        <source>Form</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current plugin status:</source>
        <translation>Текущее состояние плагина:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Is working</source>
        <translation>работает</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Set mode for all accounts</source>
        <translation>Установить для всех аккаунтов</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>You have no Oscar, Jabber or MRIM accounts.</source>
        <translation>У вас нет учетных записей ICQ, Jabber или Mail.ru агента.</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Music Player</source>
        <translation>Музыкальный плеер</translation>
    </message>
    <message>
        <source>Hostname</source>
        <translation type="obsolete">Имя  хоста</translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="obsolete">Порт</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Пароль</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../plugins/nowplaying/src/nowplaying.cpp" line="-236"/>
        <source>Now Playing</source>
        <translation>Сейчас играет</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Now playing plugin</source>
        <translation>Плагин «Сейчас играет»</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Now Playing Mpris</source>
        <translation></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mpris support for now playing plugin</source>
        <translation>Поддержка Mpris для now playing плагина</translation>
    </message>
    <message>
        <source>Amarok 2 support for now playing plugin</source>
        <translation type="obsolete">Поддержка Amarok2 для плагина now playing</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location line="-9"/>
        <location line="+3"/>
        <location line="+3"/>
        <source>Developer</source>
        <translation>Разработчик</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::nowplaying::SettingsUI</name>
    <message>
        <location filename="../../plugins/nowplaying/src/settingsui.cpp" line="+53"/>
        <source>No player</source>
        <translation type="unfinished">Фонограф выключен :(</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>working</source>
        <translation>работает</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>not working</source>
        <translation>не работает</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start</source>
        <translation>Пуск</translation>
    </message>
</context>
</TS>
